==> nvflare-2.4.0rc5-py3-none-any.whl: nvflare/client/__init__.py <==
# Copyright (c) 2023, NVIDIA CORPORATION.  All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# https://github.com/microsoft/pylance-release/issues/856

from nvflare.app_common.abstract.fl_model import FLModel as FLModel
from nvflare.app_common.abstract.fl_model import ParamsType as ParamsType

from .api import DataExchangeException as DataExchangeException
from .api import clear as clear
from .api import get_config as get_config
from .api import get_job_id as get_job_id
from .api import get_site_name as get_site_name
from .api import get_total_rounds as get_total_rounds
from .api import init as init
from .api import is_evaluate as is_evaluate
from .api import is_running as is_running
from .api import is_submit_model as is_submit_model
from .api import is_train as is_train
from .api import receive as receive
from .api import receive_global_model as receive_global_model
from .api import send as send
from .api import system_info as system_info
from .decorator import evaluate as evaluate
from .decorator import train as train

==> nvflare-2.6.0rc5-py3-none-any.whl: nvflare/client/__init__.py <==
# Copyright (c) 2023, NVIDIA CORPORATION.  All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# https://github.com/microsoft/pylance-release/issues/856

from nvflare.apis.analytix import AnalyticsDataType as AnalyticsDataType
from nvflare.app_common.abstract.fl_model import FLModel as FLModel
from nvflare.app_common.abstract.fl_model import ParamsType as ParamsType

from .api import get_config as get_config
from .api import get_job_id as get_job_id
from .api import get_site_name as get_site_name
from .api import init as init
from .api import is_evaluate as is_evaluate
from .api import is_running as is_running
from .api import is_submit_model as is_submit_model
from .api import is_train as is_train
from .api import log as log
from .api import receive as receive
from .api import send as send
from .api import shutdown as shutdown
from .api import system_info as system_info
from .decorator import evaluate as evaluate
from .decorator import train as train
from .ipc.ipc_agent import IPCAgent
